PDF.js viewer

Highlight All Match Case
Match Diacritics Whole Words
Highlight color
Thickness
Show all
Color
Size
Color
Thickness
Opacity
Current Page
Enter the password to open this PDF file:
File name:

-

File size:

-

Title:

-

Author:

-

Subject:

-

Keywords:

-

Creation Date:

-

Modification Date:

-

Creator:

-

PDF Producer:

-

PDF Version:

-

Page Count:

-

Page Size:

-

Fast Web View:

-

Choose an option Alt text (alternative text) helps when people can’t see the image or when it doesn’t load.
Add a description
Aim for 1-2 sentences that describe the subject, setting, or actions.
Mark as decorative
This is used for ornamental images, like borders or watermarks.
Edit alt text (image description)
Short description for people who can’t see the image or when the image doesn’t load.
This alt text was created automatically and may be inaccurate. Learn more
Create alt text automatically
Downloading alt text AI model (0 of 0 MB)
Couldn’t create alt text automatically Please write your own alt text or try again later.
Image alt text settings
Automatic alt text
Create alt text automatically
Suggests descriptions to help people who can’t see the image or when the image doesn’t load. Learn more
Alt text AI model (180MB)
Runs locally on your device so your data stays private. Required for automatic alt text.
Alt text editor
Show alt text editor right away when adding an image
Helps you make sure all your images have alt text.
Preparing document for printing…
0%